@@ -24,7 +24,7 @@ class fixture(object):
             return partial(self.thing, instance)
 
 
-class before(object):
+class base(object):
 
     def __init__(self, thing):
         self.thing = thing
@@ -33,44 +33,31 @@ class before(object):
         self.thing(instance)
 
 
-class after(object):
-
-    def __init__(self, thing):
-        self.thing = thing
-
-    def __call__(self, instance):
-        self.thing(instance)
+class before(base):
+    pass
 
 
-class around(object):
+class after(base):
+    pass
 
-    def __init__(self, thing):
-        self.thing = thing
 
-    def __call__(self, instance):
-        return self.thing(instance)
+class around(base):
+    pass
 
 
 class patcher(object):
 
-    class wrapper(object):
-
-        def __init__(self, func, patcher):
-            self.func = func
-            self.patcher = patcher
-
-        def __call__(self, instance):
-            return patch(
-                self.patcher.target,
-                self.func(instance),
-                *self.patcher.args,
-                **self.patcher.kwargs
-            )
-
-    def __init__(self, target, *args, **kwargs):
-        self.target = target
+    def __init__(self, *args, **kwargs):
         self.args = args
         self.kwargs = kwargs
+        self.func = None
 
     def __call__(self, func):
-        return self.wrapper(func, self)
+        self.func = func
+        return self
+
+    def build_patch(self, instance):
+        if self.func:
+            self.kwargs['new'] = self.func(instance)
+
+        return patch(*self.args, **self.kwargs)
